==> estateplat-common-1.2.4-20201112.060606-496-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzdBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGyJzd;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGyJzdBdc extends KttGyJzd {
    private String dfjblxdm;
    private String dfjblxmc;
    private String dfjzdlxdm;
    private String dfjzdlxmc;
    @XmlAttribute(
            name = "DFJBLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxdm() {
        return dfjblxdm;
    }

    public void setDfjblxdm(String dfjblxdm) {
        this.dfjblxdm = dfjblxdm;
    }
    @XmlAttribute(
            name = "DFJBLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjblxmc() {
        return dfjblxmc;
    }

    public void setDfjblxmc(String dfjblxmc) {
        this.dfjblxmc = dfjblxmc;
    }
    @XmlAttribute(
            name = "DFJZDLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxdm() {
        return dfjzdlxdm;
    }

    public void setDfjzdlxdm(String dfjzdlxdm) {
        this.dfjzdlxdm = dfjzdlxdm;
    }
    @XmlAttribute(
            name = "DFJZDLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfjzdlxmc() {
        return dfjzdlxmc;
    }

    public void setDfjzdlxmc(String dfjzdlxmc) {
        this.dfjzdlxmc = dfjzdlxmc;
    }
}

==> estateplat-common-1.2.4-20201113.091216-505-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/KttGyJzdBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.KttGyJzd;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class KttGyJzdBdc extends KttGyJzd {
    private String dfjblxdm;
    private String dfjblxmc;
    private String dfjzdlxdm;
    private String dfjzdlxmc;
    @XmlAttribute(
            name = "DFJBLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjblxdm() {
        return dfjblxdm;
    }

    public void setDfjblxdm(String dfjblxdm) {
        this.dfjblxdm = dfjblxdm;
    }
    @XmlAttribute(
            name = "DFJBLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjblxmc() {
        return dfjblxmc;
    }

    public void setDfjblxmc(String dfjblxmc) {
        this.dfjblxmc = dfjblxmc;
    }
    @XmlAttribute(
            name = "DFJZDLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzdlxdm() {
        return dfjzdlxdm;
    }

    public void setDfjzdlxdm(String dfjzdlxdm) {
        this.dfjzdlxdm = dfjzdlxdm;
    }
    @XmlAttribute(
            name = "DFJZDLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringNoNullAdapter.class)
    public String getDfjzdlxmc() {
        return dfjzdlxmc;
    }

    public void setDfjzdlxmc(String dfjzdlxmc) {
        this.dfjzdlxmc = dfjzdlxmc;
    }
}
